@@ -1,6 +1,6 @@
 /*  $Id$
  *
- *  Copyright © 2008-2009 Jérôme Guelfucci <jeromeg@xfce.org>
+ *  Copyright © 2024 André Miranda <andreldm@xfce.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,29 +20,14 @@
 #ifndef __HAVE_CAPTURE_H__
 #define __HAVE_CAPTURE_H__
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include "screenshooter-global.h"
-
-#ifdef HAVE_XFIXES
-#include <X11/extensions/Xfixes.h>
-#endif
-#include <X11/extensions/shape.h>
-#include <gdk/gdkkeysyms.h>
-#include <gdk/gdkx.h>
-#include <glib.h>
-#include <unistd.h>
-
-#include <libxfce4util/libxfce4util.h>
+#include <gdk/gdk.h>
 
 
 
 GdkPixbuf
-*screenshooter_take_screenshot   (gint     region,
-                                  gint     delay,
-                                  gboolean show_mouse,
-                                  gboolean plugin);
+*screenshooter_capture_screenshot (gint     region,
+                                   gint     delay,
+                                   gboolean show_mouse,
+                                   gboolean show_border);
 
 #endif
