@@ -20,41 +20,52 @@
 #ifndef HAVE_GLOBAL_H
 #define HAVE_GLOBAL_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <glib.h>
 #include <gtk/gtk.h>
 
+
+
 /* Possible actions */
 enum {
-  ACTION_0,
-  SAVE,
-  CLIPBOARD,
-  OPEN,
-  UPLOAD,
-  UPLOAD_IMGUR,
+  NONE = 0,
+  SAVE = 1,
+  CLIPBOARD = 2,
+  OPEN = 4,
+  CUSTOM_ACTION = 8,
 };
 
 
 
+/* Callback function to be called when execution is finalized */
+typedef void (*ScreenshotFinalizeCallback) (gboolean action_executed , gpointer data);
+
+
+
 /* Struct to store the screenshot options */
 typedef struct
 {
   gint region;
   gint show_save_dialog;
   gint show_mouse;
+  gint show_border;
   gint delay;
   gint action;
-  gboolean plugin;
   gboolean action_specified;
+  gboolean region_specified;
   gboolean timestamp;
+  gboolean path_is_dir;
+  gboolean show_in_folder;
   gchar *screenshot_dir;
   gchar *title;
   gchar *app;
+  gchar *custom_action_name;
+  gchar *custom_action_command;
+  GAppInfo *app_info;
   gchar *last_user;
+  gchar *last_extension;
   GdkPixbuf *screenshot;
+  ScreenshotFinalizeCallback finalize_callback;
+  gpointer finalize_callback_data;
 }
 ScreenshotData;
 
@@ -68,4 +79,20 @@ enum {
   SELECT,
 };
 
+
+
+/* Struct to store the preference dialog options */
+typedef struct {
+    GtkWidget *name, *cmd, *tree_view;
+    GtkListStore *liststore;
+    GtkTreeSelection *selection;
+}
+CustomActionDialogData;
+
+
+/* Application-defined ids for dialog response */
+enum {
+    GTK_RESPONSE_PREFERENCES = 0
+};
+
 #endif
