@@ -200,9 +200,9 @@ screenshooter_read_rc_file (const gchar *file, ScreenshotData *sd)
   sd->show_in_folder = show_in_folder;
   sd->custom_action_command = last_custom_action_command;
 
-  /* Under Wayland force FULLSCREEN region */
+  /* Under Wayland force FULLSCREEN region if a non supported region is loaded */
 #ifdef ENABLE_WAYLAND
-  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()) && sd->region == ACTIVE_WINDOW)
     {
       sd->region = FULLSCREEN;
     }
@@ -517,6 +517,7 @@ screenshooter_show_file_in_folder (const gchar *save_location)
 {
   GDBusProxy *proxy;
   GVariantBuilder *builder;
+  GVariant *variant;
   gchar *uri, *startup_id;
 
   if (save_location == NULL)
@@ -535,9 +536,12 @@ screenshooter_show_file_in_folder (const gchar *save_location)
   builder = g_variant_builder_new (G_VARIANT_TYPE ("as"));
   g_variant_builder_add (builder, "s", uri);
 
-  g_dbus_proxy_call_sync (proxy, "ShowItems",
-                          g_variant_new ("(ass)", builder, startup_id),
-                          G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
+  variant = g_dbus_proxy_call_sync (proxy, "ShowItems",
+                                    g_variant_new ("(ass)", builder, startup_id),
+                                    G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
+  g_object_unref (proxy);
+  if (variant != NULL)
+    g_variant_unref (variant);
 
   g_variant_builder_unref (builder);
   g_free (startup_id);
